<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage Vivid Blog Pro
 * @since Vivid Blog Pro 1.0.0
 */

// Add Service section
$wp_customize->add_section( 'vivid_blog_pro_service_section', array(
	'title'             => esc_html__( 'Services','vivid-blog-pro' ),
	'description'       => esc_html__( 'Services Section options.', 'vivid-blog-pro' ),
	'panel'             => 'vivid_blog_pro_front_page_panel',
) );

// Service content enable control and setting
$wp_customize->add_setting( 'vivid_blog_pro_theme_options[service_section_enable]', array(
	'default'			=> 	$options['service_section_enable'],
	'sanitize_callback' => 'vivid_blog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Vivid_Blog_Pro_Switch_Control( $wp_customize, 'vivid_blog_pro_theme_options[service_section_enable]', array(
	'label'             => esc_html__( 'Service Section Enable', 'vivid-blog-pro' ),
	'section'           => 'vivid_blog_pro_service_section',
	'on_off_label' 		=> vivid_blog_pro_switch_options(),
) ) );

// service title setting and control
$wp_customize->add_setting( 'vivid_blog_pro_theme_options[service_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['service_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'vivid_blog_pro_theme_options[service_title]', array(
	'label'           	=> esc_html__( 'Title', 'vivid-blog-pro' ),
	'section'        	=> 'vivid_blog_pro_service_section',
	'active_callback' 	=> 'vivid_blog_pro_is_service_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'vivid_blog_pro_theme_options[service_title]', array(
		'selector'            => '#business-services .wrapper h2.business-section-title',
		'settings'            => 'vivid_blog_pro_theme_options[service_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'vivid_blog_pro_service_title_partial',
    ) );
}

// service sub_title setting and control
$wp_customize->add_setting( 'vivid_blog_pro_theme_options[service_description]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['service_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'vivid_blog_pro_theme_options[service_description]', array(
	'label'           	=> esc_html__( 'Service Short Description', 'vivid-blog-pro' ),
	'section'        	=> 'vivid_blog_pro_service_section',
	'active_callback' 	=> 'vivid_blog_pro_is_service_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'vivid_blog_pro_theme_options[service_description]', array(
		'selector'            => '#business-services .wrapper p.business-section-subtitle',
		'settings'            => 'vivid_blog_pro_theme_options[service_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'vivid_blog_pro_service_description_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'vivid_blog_pro_theme_options[service_count]', array(
	'default'          	=> $options['service_count'],
	'sanitize_callback' => 'vivid_blog_pro_sanitize_number_range',
	'validate_callback' => 'vivid_blog_pro_validate_service_count',
) );

$wp_customize->add_control( 'vivid_blog_pro_theme_options[service_count]', array(
	'label'             => esc_html__( 'Number of Services', 'vivid-blog-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 9. Please input the valid number and save. Then refresh the page to see the change.', 'vivid-blog-pro' ),
	'section'           => 'vivid_blog_pro_service_section',
	'active_callback'   => 'vivid_blog_pro_is_service_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 9,
		'style' => 'width: 100px;'
		),
) );


// Service content type control and setting
$wp_customize->add_setting( 'vivid_blog_pro_theme_options[service_content_type]', array(
	'default'          	=> $options['service_content_type'],
	'sanitize_callback' => 'vivid_blog_pro_sanitize_select',
) );

$wp_customize->add_control( 'vivid_blog_pro_theme_options[service_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'vivid-blog-pro' ),
	'section'           => 'vivid_blog_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'vivid_blog_pro_is_service_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'vivid-blog-pro' ),
		'post' 		=> esc_html__( 'Post', 'vivid-blog-pro' ),
		'category' 	=> esc_html__( 'Category', 'vivid-blog-pro' ),
	),
) );


for ( $i = 1; $i <= $options['service_count']; $i++ ) :

		// service note control and setting
		$wp_customize->add_setting( 'vivid_blog_pro_theme_options[service_content_icon_' . $i . ']', array(
			'sanitize_callback' => 'sanitize_text_field',
		) );

		$wp_customize->add_control( new Vivid_Blog_Pro_Icon_Picker( $wp_customize, 'vivid_blog_pro_theme_options[service_content_icon_' . $i . ']', array(
			'label'             => sprintf( esc_html__( 'Select Icon %d', 'vivid-blog-pro' ), $i ),
			'section'           => 'vivid_blog_pro_service_section',
			'active_callback'	=> 'vivid_blog_pro_is_service_section_enable',
		) ) );
	

	// service pages drop down chooser control and setting
	$wp_customize->add_setting( 'vivid_blog_pro_theme_options[service_content_page_' . $i . ']', array(
		'sanitize_callback' => 'vivid_blog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Vivid_Blog_Pro_Dropdown_Chooser( $wp_customize, 'vivid_blog_pro_theme_options[service_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'vivid-blog-pro' ), $i ),
		'section'           => 'vivid_blog_pro_service_section',
		'choices'			=> vivid_blog_pro_page_choices(),
		'active_callback'	=> 'vivid_blog_pro_is_service_section_content_page_enable',
	) ) );

	// service posts drop down chooser control and setting
	$wp_customize->add_setting( 'vivid_blog_pro_theme_options[service_content_post_' . $i . ']', array(
		'sanitize_callback' => 'vivid_blog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Vivid_Blog_Pro_Dropdown_Chooser( $wp_customize, 'vivid_blog_pro_theme_options[service_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'vivid-blog-pro' ), $i ),
		'section'           => 'vivid_blog_pro_service_section',
		'choices'			=> vivid_blog_pro_post_choices(),
		'active_callback'	=> 'vivid_blog_pro_is_service_section_content_post_enable',
	) ) );

	// service hr setting and control
	$wp_customize->add_setting( 'vivid_blog_pro_theme_options[service_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Vivid_Blog_Pro_Customize_Horizontal_Line( $wp_customize, 'vivid_blog_pro_theme_options[service_hr_'. $i .']',
		array(
			'section'         => 'vivid_blog_pro_service_section',
			'active_callback' => 'vivid_blog_pro_is_service_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'vivid_blog_pro_theme_options[service_content_category]', array(
	'sanitize_callback' => 'vivid_blog_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Vivid_Blog_Pro_Dropdown_Taxonomies_Control( $wp_customize,'vivid_blog_pro_theme_options[service_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'vivid-blog-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'vivid-blog-pro' ),
	'section'           => 'vivid_blog_pro_service_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'vivid_blog_pro_is_service_section_content_category_enable'
) ) );
