<?php
/**
 * Team Section options
 *
 * @package Theme Palace
 * @subpackage Vivid Blog Pro
 * @since Vivid Blog Pro 1.0.0
 */

// Add Team section
$wp_customize->add_section( 'vivid_blog_pro_team_section', array(
	'title'             => esc_html__( 'Team','vivid-blog-pro' ),
	'description'       => esc_html__( 'Team Section options.', 'vivid-blog-pro' ),
    'panel'             => 'vivid_blog_pro_front_page_panel',
    
) );

// Team content enable control and setting
$wp_customize->add_setting( 'vivid_blog_pro_theme_options[team_section_enable]', array(
	'default'			=> 	$options['team_section_enable'],
	'sanitize_callback' => 'vivid_blog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Vivid_Blog_Pro_Switch_Control( $wp_customize, 'vivid_blog_pro_theme_options[team_section_enable]', array(
	'label'             => esc_html__( 'Team Section Enable', 'vivid-blog-pro' ),
	'section'           => 'vivid_blog_pro_team_section',
	'on_off_label' 		=> vivid_blog_pro_switch_options(),
) ) );

// team title setting and control
$wp_customize->add_setting( 'vivid_blog_pro_theme_options[team_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['team_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'vivid_blog_pro_theme_options[team_title]', array(
	'label'           	=> esc_html__( 'Title', 'vivid-blog-pro' ),
	'section'        	=> 'vivid_blog_pro_team_section',
	'active_callback' 	=> 'vivid_blog_pro_is_team_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'vivid_blog_pro_theme_options[team_title]', array(
		'selector'            => '#business-team .wrapper h2.business-section-title',
		'settings'            => 'vivid_blog_pro_theme_options[team_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'vivid_blog_pro_team_title_partial',
    ) );
}

    // team description setting and control
    $wp_customize->add_setting( 'vivid_blog_pro_theme_options[team_description]', array(
        'sanitize_callback' => 'sanitize_textarea_field',
        'default'			=> $options['team_description'],
        'transport'			=> 'postMessage',
    ) );

    $wp_customize->add_control( 'vivid_blog_pro_theme_options[team_description]', array(
        'label'           	=> esc_html__( 'Description', 'vivid-blog-pro' ),
        'section'        	=> 'vivid_blog_pro_team_section',
        'active_callback' 	=> 'vivid_blog_pro_is_team_section_enable',
        'type'				=> 'textarea',
	) );
	
	// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'vivid_blog_pro_theme_options[team_description]', array(
		'selector'            => '#business-team .wrapper p.business-section-subtitle',
		'settings'            => 'vivid_blog_pro_theme_options[team_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'vivid_blog_pro_team_description_partial',
    ) );
}

// team post number control and setting
$wp_customize->add_setting( 'vivid_blog_pro_theme_options[team_count]', array(
	'default'          	=> $options['team_count'],
	'sanitize_callback' => 'vivid_blog_pro_sanitize_number_range',
	'validate_callback' => 'vivid_blog_pro_validate_team_count',
) );

$wp_customize->add_control( 'vivid_blog_pro_theme_options[team_count]', array(
	'label'             => esc_html__( 'Number of Teams', 'vivid-blog-pro' ),
	'description'       => esc_html__( 'Note: Min 4 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'vivid-blog-pro' ),
	'section'           => 'vivid_blog_pro_team_section',
	'active_callback'   => 'vivid_blog_pro_is_team_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 4,
		'max'	=> 8,
		'style' => 'width: 100px;'
		),
) );

// Team content type control and setting
$wp_customize->add_setting( 'vivid_blog_pro_theme_options[team_content_type]', array(
	'default'          	=> $options['team_content_type'],
	'sanitize_callback' => 'vivid_blog_pro_sanitize_select',
) );

$wp_customize->add_control( 'vivid_blog_pro_theme_options[team_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'vivid-blog-pro' ),
	'section'           => 'vivid_blog_pro_team_section',
	'type'				=> 'select',
	'active_callback' 	=> 'vivid_blog_pro_is_team_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'vivid-blog-pro' ),
		'post' 		=> esc_html__( 'Post', 'vivid-blog-pro' ),
		'category' 	=> esc_html__( 'Category', 'vivid-blog-pro' ),
	),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'vivid_blog_pro_theme_options[team_content_category]', array(
	'sanitize_callback' => 'vivid_blog_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Vivid_Blog_Pro_Dropdown_Taxonomies_Control( $wp_customize,'vivid_blog_pro_theme_options[team_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'vivid-blog-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'vivid-blog-pro' ),
	'section'           => 'vivid_blog_pro_team_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'vivid_blog_pro_is_team_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['team_count']; $i++ ) :
	// team pages drop down chooser control and setting
	$wp_customize->add_setting( 'vivid_blog_pro_theme_options[team_content_page_' . $i . ']', array(
		'sanitize_callback' => 'vivid_blog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Vivid_Blog_Pro_Dropdown_Chooser( $wp_customize, 'vivid_blog_pro_theme_options[team_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'vivid-blog-pro' ), $i ),
		'section'           => 'vivid_blog_pro_team_section',
		'choices'			=> vivid_blog_pro_page_choices(),
		'active_callback'	=> 'vivid_blog_pro_is_team_section_content_page_enable',
	) ) );

	// team posts drop down chooser control and setting
	$wp_customize->add_setting( 'vivid_blog_pro_theme_options[team_content_post_' . $i . ']', array(
		'sanitize_callback' => 'vivid_blog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Vivid_Blog_Pro_Dropdown_Chooser( $wp_customize, 'vivid_blog_pro_theme_options[team_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'vivid-blog-pro' ), $i ),
		'section'           => 'vivid_blog_pro_team_section',
		'choices'			=> vivid_blog_pro_post_choices(),
		'active_callback'	=> 'vivid_blog_pro_is_team_section_content_post_enable',
	) ) );

	
	// team position setting and control
	$wp_customize->add_setting( 'vivid_blog_pro_theme_options[team_position_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'vivid_blog_pro_theme_options[team_position_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Position %d', 'vivid-blog-pro' ), $i ),
		'section'        	=> 'vivid_blog_pro_team_section',
		'active_callback' 	=> 'vivid_blog_pro_is_team_section_enable',
		'type'				=> 'text',
	) );

	// team social
	$wp_customize->add_setting( 'vivid_blog_pro_theme_options[team_social_' . $i. ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new Vivid_Blog_Pro_Multi_Input_Custom_Control( $wp_customize, 'vivid_blog_pro_theme_options[team_social_' . $i. ']', array(
		'label'             => esc_html__( 'Social ', 'vivid-blog-pro' ),
		'button_text'       => esc_html__( 'Add social.', 'vivid-blog-pro' ),
		'section'           => 'vivid_blog_pro_team_section',
		'active_callback' 	=> 'vivid_blog_pro_is_team_section_enable',
	) ) );

	// team hr setting and control
	$wp_customize->add_setting( 'vivid_blog_pro_theme_options[team_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Vivid_Blog_Pro_Customize_Horizontal_Line( $wp_customize, 'vivid_blog_pro_theme_options[team_hr_'. $i .']',
		array(
			'section'         => 'vivid_blog_pro_team_section',
			'active_callback' => 'vivid_blog_pro_is_team_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;

