<?php
/**
 * About section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Vivid Blog Pro
 * @since Vivid Blog Pro 1.0.0
 */
if ( ! function_exists( 'vivid_blog_pro_add_about_section' ) ) :
    /**
    * Add about section
    *
    *@since Vivid Blog Pro 1.0.0
    */
    function vivid_blog_pro_add_about_section() {
    	$options = vivid_blog_pro_get_theme_options();
        // Check if about is enabled on frontpage
        $about_enable = apply_filters( 'vivid_blog_pro_section_status', true, 'about_section_enable' );

        if ( true !== $about_enable ) {
            return false;
        }
        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'vivid_blog_pro_filter_about_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render about section now.
        vivid_blog_pro_render_about_section( $section_details );
    }
endif;

if ( ! function_exists( 'vivid_blog_pro_get_about_section_details' ) ) :
    /**
    * about section details.
    *
    * @since Vivid Blog Pro 1.0.0
    * @param array $input about section details.
    */
    function vivid_blog_pro_get_about_section_details( $input ) {
        $options = vivid_blog_pro_get_theme_options();

        // Content type.
        $about_content_type  = $options['about_content_type'];
        
        $content = array();
        switch ( $about_content_type ) {
        	
            case 'custom':
                $custom['title']        = ! empty( $options['about_title'] ) ? $options['about_title'] : '';
                $custom['excerpt']      = ! empty( $options['about_description'] ) ? $options['about_description'] : '';
                $custom['image']        = ! empty( $options['about_image'] ) ? $options['about_image'] : '';
                $custom['url']          = ! empty( $options['about_btn_link'] ) ? $options['about_btn_link'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['about_content_page'] ) ? $options['about_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['about_content_post'] ) ? $options['about_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    'ignore_sticky_posts' => true,
                    );
            break;

            default:
            break;
        }

        if ( 'custom' !== $about_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['author']    = vivid_blog_pro_author();
                    $page_post['excerpt']   = vivid_blog_pro_trim_content( 30 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'vivid_blog_pro_filter_about_section_details', 'vivid_blog_pro_get_about_section_details' );


if ( ! function_exists( 'vivid_blog_pro_render_about_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since Vivid Blog Pro 1.0.0
   *
   */
   function vivid_blog_pro_render_about_section( $content_details = array() ) {
        $options = vivid_blog_pro_get_theme_options();
        $about_content_type  = $options['about_content_type'];
        $readmore = ! empty( $options['about_btn_title'] ) ? $options['about_btn_title'] : esc_html__( 'Read More', 'vivid-blog-pro' );

        if ( empty( $content_details ) ) {
            return;
        } 

        if ( $options['home_layout'] == 'default-design' ):

        foreach ( $content_details as $content ) : ?>

            <div id="about-us" class="relative page-section">
                <div class="wrapper">
                    <article class="<?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-post-thumbnail">
                        <?php if ( ! empty( $content['image'] ) ) : ?>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                            </div><!-- .featured-image -->
                        <?php endif; ?>

                        <div class="entry-container">
                            <div class="section-header">
                                <?php if ( ! empty( $options['about_sub_title'] ) ) : ?>
                                    <p class="section-subtitle"><?php echo esc_html( $options['about_sub_title'] ); ?></p>
                                <?php endif; 

                                if ( ! empty( $content['title'] ) ) : ?>
                                    <h2 class="section-title"><?php echo esc_html( $content['title'] ); ?></h2>
                                <?php endif; ?>
                            </div><!-- .section-header -->

                            <?php if ( ! empty( $content['excerpt'] ) ) : ?>
                                <div class="section-content">
                                    <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                </div><!-- .entry-content -->
                            <?php endif; 

                            if ( 'post' == $about_content_type ) : ?>
                                <div class="section-meta">
                                    <?php 
                                        vivid_blog_pro_posted_on( $content['id'] );
                                        echo wp_kses_post( $content['author'] );
                                    ?>
                                </div><!-- .section-meta -->
                            <?php endif; 

                            if ( ! empty( $content['url'] ) ) : ?>
                                <div class="read-more">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $readmore ); ?></a>
                                </div><!-- .read-more -->
                            <?php endif; ?>
                        </div><!-- .entry-container -->
                    </article>
                </div><!-- .wrapper -->
            </div><!-- #about-me -->

        <?php endforeach;
        endif;

                if ( $options['home_layout'] == 'second-design' ):

                    foreach ( $content_details as $content ) : ?>

                <div id="business-about-us" class="relative page-section">
                    <div class="wrapper">
                        <article class="<?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-post-thumbnail">
                            <?php if ( ! empty( $content['image'] ) ) : ?>
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                </div><!-- .featured-image -->
                            <?php endif; ?>

                            <div class="entry-container">
                                <?php if ( ! empty( $content['title'] ) ) : ?>
                                    
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                <?php endif;

                                if ( ! empty( $content['excerpt'] ) ) : ?>

                                <div class="entry-content">
                                    <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                </div><!-- .entry-content -->

                            <?php endif; ?>

                            <div class="business-read-more">
                                <a href="<?php echo esc_url( $content['url'] ); ?>">Read More</a>
                            </div><!-- .business-read-more -->
                        </div><!-- .entry-container -->
                    </article>
                </div><!-- .wrapper -->
            </div>

            <?php
            endforeach;
        endif;
    }
endif;